'use client'

import { useEffect, useState } from 'react'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { 
  FiTrendingUp,
  FiPackage,
  FiDollarSign,
  FiPieChart,
  FiShoppingBag,
} from 'react-icons/fi'
import { reportService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import { Statistics } from '@/types/statistics'


export default function ReportsPage() {
  const [statistics, setStatistics] = useState<Statistics | null>(null)
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  const { user } = useUser()

  useEffect(() => {
    let mounted = true
    
    const fetchData = async () => {
      if (!user?.token) {
        setError('Oturum bilgisi bulunamadı')
        setLoading(false)
        return
      }

      try {
        const response = await reportService.static(user.token, user.role)
        
        if (mounted) {
          if (response.data?.data) {
            setStatistics(response.data.data)
            setError(null)
          } else {
            setError('Veri formatı geçersiz')
          }
        }
      } catch (error: any) {
        if (mounted) {
          setError(error.response?.data?.message || 'Veriler yüklenirken bir hata oluştu')
        }
      } finally {
        if (mounted) {
          setLoading(false)
        }
      }
    }

    fetchData()

    return () => {
      mounted = false // Component unmount olduğunda istekleri temizle
    }
  }, [user?.token]) // token değiştiğinde yeniden çağır

  // Hata durumunu göster
  if (error) {
    return (
      <DashboardLayout>
        <div className="text-center text-red-500 dark:text-red-400 p-4">
          {error}
        </div>
      </DashboardLayout>
    )
  }

  const stats = statistics ? [  
    { 
      label: 'Günlük Gelir', 
      value: `₺${statistics.daily_income?.amount.toLocaleString()}`, 
      change: `${statistics.daily_income?.increase_percentage > 0 ? '+' : ''}${statistics.daily_income?.increase_percentage}%`,
      icon: FiDollarSign, 
      color: 'from-fuchsia-500 to-purple-600' 
    },
    { 
      label: 'Aylık Gelir', 
      value: `₺${statistics.monthly_income?.amount.toLocaleString()}`, 
      change: `${statistics.monthly_income?.increase_percentage > 0 ? '+' : ''}${statistics.monthly_income?.increase_percentage}%`,
      icon: FiPieChart, 
      color: 'from-blue-500 to-cyan-600' 
    },
    { 
      label: 'Toplam Sipariş', 
      value: statistics.orders?.monthly.toString(), 
      change: `${((statistics.orders?.monthly / statistics.orders?.total) * 100).toFixed(1)}%`,
      icon: FiShoppingBag, 
      color: 'from-emerald-500 to-green-600' 
    },
  ] : []

  if (loading) {
    return (
      <DashboardLayout>
        <div className="space-y-6">
          <div className="animate-pulse">
            {/* İstatistik Kartları Loading */}
            <div className="grid grid-cols-1 sm:grid-cols-3 lg:grid-cols-3 gap-4">
              {[1, 2, 3].map((i) => (
                <div
                  key={i}
                  className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm
                         border border-slate-200/50 dark:border-slate-700/50
                         rounded-2xl p-6 h-32"
                />
              ))}
            </div>
            
            {/* Grafik Loading */}
            <div className="mt-6 grid grid-cols-1 lg:grid-cols-3 gap-6">
              <div className="lg:col-span-2 bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm 
                           border border-slate-200/50 dark:border-slate-700/50 
                           rounded-2xl h-96" />
              <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm 
                           border border-slate-200/50 dark:border-slate-700/50 
                           rounded-2xl h-96" />
            </div>
          </div>
        </div>
      </DashboardLayout>
    )
  }

  if (!statistics) {
    return (
      <DashboardLayout>
        <div className="text-center text-slate-500 dark:text-slate-400">
          Veriler yüklenemedi. Lütfen daha sonra tekrar deneyin.
        </div>
      </DashboardLayout>
    )
  }

  // Günlük gelir grafiği için son 7 günü oluşturalım
  const last7Days = Array.from({length: 7}, (_, i) => {
    const date = new Date();
    date.setDate(date.getDate() - i);
    return date.toLocaleDateString('tr-TR', { weekday: 'short', day: 'numeric' });
  }).reverse();

  // Günlük veriyi hazırlayalım
  const dailyIncomeAmount = statistics?.daily_income?.amount || 0
  const dailyIncomeData = last7Days.map(day => {
    const dayData = statistics?.daily_income?.daily_data?.find(data => {
      const date = new Date(data.date);
      return date.toLocaleDateString('tr-TR', { weekday: 'short', day: 'numeric' }) === day;
    });
    
    return {
      time: day,
      amount: dayData?.amount || 0
    };
  });

  return (
    <DashboardLayout>
      <div className="space-y-6">
        {/* Başlık */}
        <div className="flex items-center justify-between">
          <div>
            <h1 className="text-2xl font-bold text-slate-800 dark:text-white">
              Raporlar ve Analizler
            </h1>
            <p className="mt-1 text-sm text-slate-500 dark:text-slate-400">
              İşletmenizin performans metrikleri ve analizleri
            </p>
          </div>
        </div>

        {/* İstatistik Kartları */}
        <div className="grid grid-cols-1 sm:grid-cols-3 lg:grid-cols-3 gap-4">
          {stats.map((stat) => (
            <div
              key={stat.label}
              className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm
                       border border-slate-200/50 dark:border-slate-700/50
                       rounded-2xl p-6 shadow-lg"
            >
              <div className={`inline-flex p-3 rounded-xl bg-gradient-to-r ${stat.color} shadow-lg mb-4`}>
                <stat.icon className="h-6 w-6 text-white" />
              </div>
              <p className="text-sm font-medium text-slate-600 dark:text-slate-400">
                {stat.label}
              </p>
              <div className="flex items-baseline gap-2 mt-1">
                <p className="text-2xl font-bold text-slate-800 dark:text-white">
                  {stat.value}
                </p>
                <span className={`text-xs font-medium px-1.5 py-0.5 rounded-full
                              ${stat.change.startsWith('+') 
                                ? 'bg-emerald-100/50 text-emerald-600 dark:bg-emerald-900/50 dark:text-emerald-400'
                                : 'bg-red-100/50 text-red-600 dark:bg-red-900/50 dark:text-red-400'
                              }`}>
                  {stat.change}
                </span>
              </div>
            </div>
          ))}
        </div>

        {/* Analiz Kartları */}
        <div className="grid grid-cols-1 lg:grid-cols-3 gap-6">
          {/* Günlük Gelir Grafiği */}
          <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm 
                       border border-slate-200/50 dark:border-slate-700/50 
                       rounded-2xl shadow-lg lg:col-span-2">
            <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
              <div className="flex items-center justify-between">
                <div className="flex items-center gap-3">
                  <div className="p-2 bg-fuchsia-50 dark:bg-fuchsia-900/50 rounded-xl">
                    <FiTrendingUp className="w-5 h-5 text-fuchsia-500" />
                  </div>
                  <div>
                    <h3 className="font-semibold text-slate-800 dark:text-white">
                      Günlük Gelir
                    </h3>
                    <p className="text-sm text-slate-500 dark:text-slate-400">
                      Son 7 günün gelir dağılımı
                    </p>
                  </div>
                </div>
                <span className="text-2xl font-bold text-slate-800 dark:text-white">
                  ₺{dailyIncomeAmount.toLocaleString()}
                </span>
              </div>
            </div>
            <div className="p-6">
              <div className="h-64 w-full overflow-x-auto">
                <div className="flex items-end justify-between h-48 gap-3 min-w-[500px]">
                  {dailyIncomeData.map((data) => {
                    const percentage = dailyIncomeAmount > 0 
                      ? (data.amount / dailyIncomeAmount) * 100 
                      : 0

                    return (
                      <div key={data.time} className="flex flex-col items-center gap-2 flex-1 group relative">
                        <div className="absolute bottom-full mb-2 opacity-0 group-hover:opacity-100 transition-opacity duration-200 z-10">
                          <div className="bg-slate-800 dark:bg-slate-700 text-white px-2 py-1 rounded text-xs whitespace-nowrap">
                            ₺{data.amount.toLocaleString()}
                          </div>
                          <div className="w-2 h-2 bg-slate-800 dark:bg-slate-700 rotate-45 absolute -bottom-1 left-1/2 -translate-x-1/2"></div>
                        </div>
                        <div 
                          className="w-full bg-gradient-to-t from-fuchsia-500 to-purple-600 rounded-t-lg transition-all duration-300 cursor-pointer hover:opacity-80"
                          style={{ 
                            height: `${Math.max(percentage, 2)}%`,
                            minHeight: '4px'
                          }}
                        />
                        <div className="text-xs font-medium text-slate-600 dark:text-slate-400 whitespace-nowrap">
                          {data.time}
                        </div>
                      </div>
                    )
                  })}
                </div>
              </div>
            </div>
          </div>

          {/* En Çok Satan Ürünler */}
          <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm 
                       border border-slate-200/50 dark:border-slate-700/50 
                       rounded-2xl shadow-lg">
            <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
              <div className="flex items-center gap-3">
                <div className="p-2 bg-emerald-50 dark:bg-emerald-900/50 rounded-xl">
                  <FiPackage className="w-5 h-5 text-emerald-500" />
                </div>
                <div>
                  <h3 className="font-semibold text-slate-800 dark:text-white">
                    En Çok Satanlar
                  </h3>
                  <p className="text-sm text-slate-500 dark:text-slate-400">
                    Bugünün en çok satan ürünleri
                  </p>
                </div>
              </div>
            </div>
            <div className="p-6">
              <div className="space-y-4">
                {statistics.top_selling_today?.map((product: any, index: number ) => (
                  <div key={product.name} className="flex items-center gap-4">
                    <div className="w-8 h-8 rounded-lg bg-gradient-to-br from-slate-500 to-slate-600 
                                flex items-center justify-center text-white font-medium">
                      {index + 1}
                    </div>
                    <div className="flex-1">
                      <h4 className="text-sm font-medium text-slate-800 dark:text-white">
                        {product.name}
                      </h4>
                      <div className="flex items-center gap-2 mt-1">
                        <span className="text-xs px-2 py-0.5 rounded-full 
                                     bg-fuchsia-100/50 dark:bg-fuchsia-900/50 
                                     text-fuchsia-600 dark:text-fuchsia-400">
                          {product.total_quantity} adet
                        </span>
                        <span className="text-xs text-slate-500 dark:text-slate-400">
                          ₺{product.total_amount.toLocaleString()}
                        </span>
                      </div>
                    </div>
                  </div>
                ))}
              </div>
            </div>
          </div>
        </div>
      </div>
    </DashboardLayout>
  )
} 